@@ -1,7 +1,5 @@
 from jinja2 import Environment, PackageLoader
 
-from strictdoc.helpers.hyperlinks import string_to_anchor_id
-
 
 class DocumentHTMLGenerator:
     env = Environment(
@@ -10,14 +8,16 @@ class DocumentHTMLGenerator:
     env.globals.update(isinstance=isinstance)
 
     @staticmethod
-    def export(document_tree, document, traceability_index, renderer):
+    def export(document_tree, document, traceability_index,
+               markup_renderer,
+               link_renderer):
         output = ""
 
         template = DocumentHTMLGenerator.env.get_template('single_document/document.jinja.html')
 
         output += template.render(document=document,
                                   traceability_index=traceability_index,
-                                  string_to_anchor_id=string_to_anchor_id,
-                                  renderer=renderer)
+                                  link_renderer=link_renderer,
+                                  renderer=markup_renderer)
 
         return output
