@@ -1,5 +1,6 @@
 import os
 
+from strictdoc.core.document_tree import DocumentTree
 from strictdoc.export.rst.writer import RSTWriter
 
 
@@ -10,9 +11,10 @@ def get_path_components(folder_path):
 
 class SingleDocumentRSTExport:
     @staticmethod
-    def export(document_tree, document, traceability_index):
+    def export(document_tree: DocumentTree, document, traceability_index):
         writer = RSTWriter()
 
-        output = writer.write(document)
+        single_or_many = len(document_tree.document_list) == 1
+        output = writer.write(document, single_or_many)
 
         return output
